import { Component, OnInit, HostListener } from '@angular/core';
import { Platform } from '@ionic/angular';
import {
  IonHeader,
  IonToolbar,
  IonTitle,
  IonContent,
  IonCard,
  IonCardTitle,
  IonCardContent,
  IonButtons, 
  IonMenuButton,
} from '@ionic/angular/standalone';
import { NgClass } from '@angular/common';
import { Chart, registerables } from 'chart.js';
import { ChartConfiguration, ChartOptions, ChartType } from "chart.js";
import { BaseChartDirective } from 'ng2-charts';

Chart.register(...registerables);
@Component({
  selector: 'app-indikator',
  templateUrl: './indikator.page.html',
  styleUrls: ['./indikator.page.scss'],
  standalone: true,
  imports: [
    IonButtons,
    IonMenuButton,
    IonHeader,
    IonToolbar,
    IonTitle,
    IonContent,
    IonCard,
    IonCardTitle,
    IonCardContent,
    NgClass,
    BaseChartDirective
  ],
})
export class IndikatorPage implements OnInit {
  public below: boolean = false;

  constructor() {}

  ngOnInit() {
    this.createChart();
  }

  createChart() {
    const canvas = document.getElementById('myChart') as HTMLCanvasElement;
    const ctx = canvas.getContext('2d');

    if (ctx) {
      // Create a gradient for the chart background
      const gradient = ctx.createLinearGradient(0, 0, 0, 400);
      gradient.addColorStop(0, 'rgba(0, 255, 0, 0.5)'); // Green area
      gradient.addColorStop(0.33, 'rgba(255, 255, 0, 0.5)'); // Yellow area
      gradient.addColorStop(0.66, 'rgba(255, 0, 0, 0.5)'); // Red area

      // Apply the gradient to the chart background
      new Chart(ctx, {
        type: 'line',
        data: {
          labels: ['January', 'February', 'March'],
          datasets: [{
            label: 'Series A',
            data: [0.5, 1.5, 2.5],
            borderColor: 'black',
            fill: true,
          }]
        },
        options: {
          responsive: true,
          scales: {
            y: {
              min: 0,
              max: 3,
              beginAtZero: true,
              ticks: {
                stepSize: 1,
                callback: function(value) {
                  return value;
                }
              }
            }
          }
        },
        plugins: [{
          beforeDraw: function (chart) {
            const ctx = chart.ctx;
            const chartArea = chart.chartArea;
            const chartHeight = chartArea.bottom - chartArea.top;

            // Calculate gradient stops
            const greenStop = chartHeight * 0.33;
            const yellowStop = chartHeight * 0.66;

            const gradient = ctx.createLinearGradient(0, chartArea.top, 0, chartArea.bottom);
            gradient.addColorStop(0, 'rgba(0, 255, 0, 0.5)');
            gradient.addColorStop(greenStop / chartHeight, 'rgba(0, 255, 0, 0.5)');
            gradient.addColorStop(greenStop / chartHeight, 'rgba(255, 255, 0, 0.5)');
            gradient.addColorStop(yellowStop / chartHeight, 'rgba(255, 255, 0, 0.5)');
            gradient.addColorStop(yellowStop / chartHeight, 'rgba(255, 0, 0, 0.5)');
            gradient.addColorStop(1, 'rgba(255, 0, 0, 0.5)');

            ctx.save();
            ctx.fillStyle = gradient;
            ctx.fillRect(chartArea.left, chartArea.top, chartArea.right - chartArea.left, chartArea.bottom - chartArea.top);
            ctx.restore();
          },
          id: ''
        }]
      });
    }
  }
}